aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/DumpGH.c12
1 files changed, 5 insertions, 7 deletions
diff --git a/src/DumpGH.c b/src/DumpGH.c
index 2e4b492..74a5426 100644
--- a/src/DumpGH.c
+++ b/src/DumpGH.c
@@ -287,13 +287,11 @@ void IOFlexIO_DumpGH (cGH *GH, int called_from)
if (print_timing_info)
CCTK_TimerStartI (myGH->checkpointTotalTimer);
- /* sync all groups */
- for (index = 0; index < CCTK_NumGroups (); index++) {
- char *gname = CCTK_GroupName (index);
-
- CCTK_SyncGroup (GH, gname);
- free (gname);
- }
+ /* sync all active groups */
+ for (index = 0; index < CCTK_NumGroups (); index++)
+ if (CCTK_IsImplementationActive (CCTK_ImpFromVarI (
+ CCTK_FirstVarIndexI (index))))
+ CCTK_SyncGroupI (GH, index);
/* get the base filename ... */
IOUtil_PrepareFilename (GH, NULL, dumpfname, called_from,